import {Injectable} from "@angular/core";
import ApiService, {AvailableVersion} from "@api/api.service";
import {DatabaseRequest} from "@api/v1/databaseRequest";
import {CacheRequest} from "@api/v1/cacheRequest";
import {CreateUserRequest} from "@api/v1/createUserRequest";
import {LoggingRequest} from "@api/v1/loggingRequest";
import {EmailRequest} from "@api/v1/emailRequest";
import {ScheduleConfigurationRequest} from "@api/v1/scheduleConfigurationRequest";
import {DateOnly} from "@model/DateOnly";

@Injectable()
export default class SetupService extends ApiService {
  public readonly basePath = 'Setup/';
  public readonly version = AvailableVersion.v1;

  public checkToken(token: string) {
    let request = this.createRequestBuilder()
      .setEndpoint('CheckToken')
      .setQueryParams({token: token})
      .setWithCredentials()
      .build;

    return this.get<boolean>(request);
  }

  public setPsql(data: DatabaseRequest) {
    let request = this.createRequestBuilder()
      .setEndpoint('SetPsql')
      .setData(data)
      .setWithCredentials()
      .build;

    return this.post<boolean>(request);
  }

  public setMysql(data: DatabaseRequest) {
    let request = this.createRequestBuilder()
      .setEndpoint('SetMysql')
      .setData(data)
      .setWithCredentials()
      .build;

    return this.post<boolean>(request);
  }

  public setSqlite(path: string | null = null) {
    let request = this.createRequestBuilder()
      .setEndpoint('SetSqlite')
      .setQueryParams({path: path})
      .setWithCredentials()
      .build;

    return this.post<boolean>(request);
  }

  public setRedis(data: CacheRequest) {
    let request = this.createRequestBuilder()
      .setEndpoint('SetRedis')
      .setData(data)
      .setWithCredentials()
      .build;

    return this.post<boolean>(request);
  }

  public setMemcached() {
    let request = this.createRequestBuilder()
      .setEndpoint('SetMemcached')
      .setWithCredentials()
      .build;

    return this.post<boolean>(request);
  }

  public createAdmin(data: CreateUserRequest) {
    let request = this.createRequestBuilder()
      .setEndpoint('CreateAdmin')
      .setData(data)
      .setWithCredentials()
      .build;

    return this.post<boolean>(request);
  }

  public setLogging(data: LoggingRequest | null = null) {
    let request = this.createRequestBuilder()
      .setEndpoint('SetLogging')
      .setData(data)
      .setWithCredentials()
      .build;

    return this.post<boolean>(request);
  }

  public setEmail(data: EmailRequest | null = null) {
    let request = this.createRequestBuilder()
      .setEndpoint('SetEmail')
      .setData(data)
      .setWithCredentials()
      .build;

    return this.post<boolean>(request);
  }

  public setSchedule(data: ScheduleConfigurationRequest) {
    data.startTerm = new DateOnly(data.startTerm).toString();

    let request = this.createRequestBuilder()
      .setEndpoint('SetSchedule')
      .setData(data)
      .setWithCredentials()
      .build;

    return this.post<boolean>(request);
  }

  public submit() {
    let request = this.createRequestBuilder()
      .setEndpoint('Submit')
      .setWithCredentials()
      .build;

    return this.post<boolean>(request);
  }

  public isConfigured() {
    return this.get<boolean>('IsConfigured');
  }
}
